-- 新每日充值
Lua_NewChargeEverydayWindow = class("Lua_NewChargeEverydayWindow", Lua_Window)
function Lua_NewChargeEverydayWindow:ctor(p)
	self:superCall("ctor", p);

	self.windowName = "Lua_NewChargeEverydayWindow";
	self.skinName = "NewChargeEverydayWindow_skin";
end

function Lua_NewChargeEverydayWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.selectIndex = nil;

	self.bar.type = UIBasicSprite.Type.Filled;
	self.bar.fillDirection = UIBasicSprite.FillDirection.Vertical;
	self.bar.fillAmount = 0;

	self.goldNum = Lua_NumberImage.new(self.content);
	self.goldNum.prefix = "ui_mrxf_";
	self.goldNum.pivot = 2;
	self.goldNum.numWidth = 22;
	self.goldNum.num = 0;
	self.goldNum:setDepth(5);
	self.goldNum:setLocation(-18, 107, 0);

	self.btnList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 200, 450));
	self.btnList:setListCell(Lua_NewChargeEverydayBtnItem, 82, 82, 1, 225, 19);
	self.btnList:setLocation(-356, -14, 0);
	self.btnList.canDrag = false;

	self.rewardList = Lua_DragList.new(self.content, 2, Vector4(0, 0, 372, 180));
	self.rewardList:setListCell(Lua_NewChargeEverydayRewardItem, 90, 100, 3);
	self.rewardList:setLocation(-30, -29.5, 0);

	self.rechargeList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 343, 392));
	self.rechargeList:setListCell(Lua_NewChargeEverydayRechargeItem, 138, 343, 1);
	self.rechargeList:setLocation(444.5, -15, 0);

	self.chargeBtn:addClickFuntion(self, self.onChargeBtnClick);

	self:addLuaEvent("TODAY_CHARGE_ITEM_CLICK", self, self.setSelected);
	self:addLuaEvent("UPDATE_NEW_CHARGE_EVERYDAY", self, self.updatePanelInfo);
	Lua_ProxyManager.getProxy("Lua_NewChargeEverydayProxy"):sOpenNewChargeEverydayWin();
end

function Lua_NewChargeEverydayWindow:setSelected(data)
	if data == nil then
		return;
	end
	self.data = data;
	
	self.selectIndex = data.index;

	self.goldNum.num = data.cond;
	self.goldNum:setNumScale(0.9, 0.9);

	local posX;
	if data.rewardArr:getSize() / 2 > 3 then
		posX = -30;
	else
		posX = -30 + (372 - math.ceil(data.rewardArr:getSize() / 2) * 100) / 2;
	end
	self.rewardList.perLine = math.ceil(data.rewardArr:getSize() / 2);
	self.rewardList:setLuaArrayData(data.rewardArr, false);
	self.rewardList:setLocation(posX, -29.5, 0);

	if data.reward_state == 0 then
		self.chargeBtn:setBtnEnable(true);
		self.chargeBtn.label = LanUtil.getValue(122513);
	elseif data.reward_state == 1 then
		self.chargeBtn:setBtnEnable(true);
		self.chargeBtn.label = LanUtil.getValue(121916);
	elseif data.reward_state == 2 then
		self.chargeBtn:setBtnEnable(false);
		self.chargeBtn.label = LanUtil.getValue(122528);
	end
	self.redDot:setEnable(data.reward_state == 1);
end

function Lua_NewChargeEverydayWindow:updatePanelInfo()
	self.btnList:setLuaArrayData(DataCenter.newChargeEverydayData.rechargeReward, false);
	self.rechargeList:setLuaArrayData(DataCenter.newChargeEverydayData.dayReward, false);
	self.curChargeTxt.text = LanUtil.formateStr(LanUtil.getValue(122540), tostring(DataCenter.newChargeEverydayData.total_gold));

	local arr = DataCenter.newChargeEverydayData.rechargeReward;
    local rewardNum=0;
	if arr:getSize() > 0 then
		if self.selectIndex == nil then
			self.btnList:setSelected(1);
		else
			for i = 1, arr:getSize() do
				if arr[i].index == self.selectIndex then
					self.btnList:moveToIndex(i, true);
					self.btnList:setSelected(i);
				end
			end
		end
	end

    if rewardNum == arr:getSize() then
        rewardNum = rewardNum + 1;
    end
    self.bar.fillAmount = rewardNum / (arr:getSize() + 1);
end

function Lua_NewChargeEverydayWindow:onChargeBtnClick(go)
	if self.data.reward_state == 0 then
		Lua_WindowUtil.openWin("Lua_ChongzhiWindow", WinParam.ACTION_OPEN);
    	Lua_WindowUtil.openWin("Lua_ChargeEverydayWindow", WinParam.ACTION_CLOSE);
	elseif self.data.reward_state == 1 then
		Lua_ProxyManager.getProxy("Lua_NewChargeEverydayProxy"):sGetRechargeRewards(self.data.index);
	end
end

function Lua_NewChargeEverydayWindow:dispose()
	if self.goldNum ~= nil then
		self.goldNum:dispose();
		self.goldNum = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.rechargeList ~= nil then
		self.rechargeList:dispose();
		self.rechargeList = nil;
	end
	self.selectIndex = nil;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_NewChargeEverydayBtnItem = class("Lua_NewChargeEverydayBtnItem", Lua_ListCell)
function Lua_NewChargeEverydayBtnItem:ctor(p)
	self:superCall("ctor", p, "NewChargeEverydayBtnItem_skin");
end

function Lua_NewChargeEverydayBtnItem:buildShowItem()
	self:superCall("buildShowItem");

	self.redDot:setEnable(false);
	self.selectSp:setEnable(false);
end

function Lua_NewChargeEverydayBtnItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	self.redDot:setEnable(data.reward_state == 1);
	self.numberTxt.text = data.cond;
end

function Lua_NewChargeEverydayBtnItem:onSelectionChange(val)
	self:superCall("onSelectionChange", val);

	if val then
		Lua_MsgUtil.callFunc("TODAY_CHARGE_ITEM_CLICK", self._data);
	end
	self.selectSp:setEnable(val);
end





--------------------------------------------------





Lua_NewChargeEverydayRewardItem = class("Lua_NewChargeEverydayRewardItem", Lua_ListCell)
function Lua_NewChargeEverydayRewardItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_NewChargeEverydayRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.toolImage = Lua_ToolImage.new(self.content);
	self.toolImage:setDepth(5);
	self.toolImage:setCanClick(false);
end

function Lua_NewChargeEverydayRewardItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	self.toolImage.data = data;
	if data.show_effect == 1 then
		self.toolImage:showRoundEff(true);
	end
end

function Lua_NewChargeEverydayRewardItem:checkOutBound(showRect)
	local rect = Lua_Rectangle.new(self.itemX - 25, self.itemY - 25, 50, 50);
	self.toolImage:showRoundEff(showRect:containeRect(rect));
end

function Lua_NewChargeEverydayRewardItem:onPlayerSoundClick(go)
    Lua_PackUtil.showItemInfo(self._data)
end

function Lua_NewChargeEverydayRewardItem:dispose()
	if self.toolImage ~= nil then
		self.toolImage:dispose();
		self.toolImage = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_NewChargeEverydayRechargeItem = class("Lua_NewChargeEverydayRechargeItem", Lua_ListCell)
function Lua_NewChargeEverydayRechargeItem:ctor(p)
	self:superCall("ctor", p, "NewChargeEverydayRechargeItem_skin");
end

function Lua_NewChargeEverydayRechargeItem:buildShowItem()
	self:superCall("buildShowItem");

	self.effectList = Array();

	self.redDot:setEnable(false);

	self.rItem = Lua_RewardItem.new(self.content);
	self.rItem:setDepth(3);
	self.rItem:setMaxShow(2);
	self.rItem:setClickWin(true);
	self.rItem:setMouseEnble(true);
	self.rItem:setItemScale(0.9, 0.9);
	self.rItem:setLocation(-119, -17);

	self.getBtn:addClickFuntion(self, self.onGetClick);
end

function Lua_NewChargeEverydayRechargeItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local total_day = DataCenter.newChargeEverydayData.total_day;
	if total_day >= data.index + 1 then
		self.chargeTxt.text = LanUtil.formateStr(LanUtil.getValue(122515), tostring(data.index + 1), tostring(total_day), tostring(data.index + 1), tostring(data.cond))
	else
		self.chargeTxt.text = LanUtil.formateStr(LanUtil.getValue(122541), tostring(data.index + 1), tostring(total_day), tostring(data.index + 1), tostring(data.cond))
	end

	if data.reward_state == 0 then
		self.getBtn.label = LanUtil.getValue(122516);
		self.getBtn:setBtnEnable(false);
		self.redDot:setEnable(false);
	elseif data.reward_state == 1 then
		self.getBtn.label = LanUtil.getValue(122516);
		self.getBtn:setBtnEnable(true);
		self.redDot:setEnable(true);
	elseif data.reward_state == 2 then
		self.getBtn.label = LanUtil.getValue(110029);
		self.getBtn:setBtnEnable(false);
		self.redDot:setEnable(false);
	end

	local arr = data.rewardArr;
	self.rItem:setRewardByToolVoList(arr);

	local item;
	for i = 1, arr:getSize() do
		if arr[i].show_effect == 1 then
			item = self.rItem:getToolImageById(arr[i].id);
			item:showRoundEff(true);
			self.effectList:add(item);
		end
	end
end

function Lua_NewChargeEverydayRechargeItem:checkOutBound(showRect)
	local rect = Lua_Rectangle.new(self.itemX, self.itemY - 55, 100, 75);
	for i = 1, self.effectList:getSize() do
		self.effectList[i]:showRoundEff(showRect:containeRect(rect));
	end
end

function Lua_NewChargeEverydayRechargeItem:onGetClick(go)
	Lua_ProxyManager.getProxy("Lua_NewChargeEverydayProxy"):sGetDayRewards(self._data.index);
end

function Lua_NewChargeEverydayRechargeItem:dispose()
	if self.effectList ~= nil then
		self.effectList:dispose();
		self.effectList:clear();
		self.effectList = nil;
	end
	if self.rItem ~= nil then
		self.rItem:dispose();
		self.rItem = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end